==> kafka-4.1.1-src.tgz: kafka-4.1.1-src/trogdor/src/main/java/org/apache/kafka/trogdor/rest/ErrorResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.trogdor.rest;

import org.apache.kafka.trogdor.common.JsonUtil;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

import java.util.Objects;

/**
 * An error response.
 */
public class ErrorResponse {
    private final int code;
    private final String message;

    @JsonCreator
    public ErrorResponse(@JsonProperty("code") int code,
                         @JsonProperty("message") String message) {
        this.code = code;
        this.message = message;
    }

    @JsonProperty
    public int code() {
        return code;
    }

    @JsonProperty
    public String message() {
        return message;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        ErrorResponse that = (ErrorResponse) o;
        return Objects.equals(code, that.code) &&
            Objects.equals(message, that.message);
    }

    @Override
    public int hashCode() {
        return Objects.hash(code, message);
    }

    @Override
    public String toString() {
        return JsonUtil.toJsonString(this);
    }
}

==> kafka-4.2.0-src.tgz: kafka-4.2.0-src/trogdor/src/main/java/org/apache/kafka/trogdor/rest/ErrorResponse.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.trogdor.rest;

import org.apache.kafka.trogdor.common.JsonUtil;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * An error response.
 */
public record ErrorResponse(int code, String message) {
    @JsonCreator
    public ErrorResponse(@JsonProperty("code") int code,
                         @JsonProperty("message") String message) {
        this.code = code;
        this.message = message;
    }

    @Override
    @JsonProperty
    public int code() {
        return code;
    }

    @Override
    @JsonProperty
    public String message() {
        return message;
    }

    @Override
    public String toString() {
        return JsonUtil.toJsonString(this);
    }
}
